#!/usr/bin/env bash

# $1: list of systems to score (absolute paths of folders containing a .stdlist.xml.gzip file)
systems=$1

# directory containing the scoring script, the .jar file, the ground-truth folders and all the needed files and scripts
scoring_dir=.

# python3 command (you must have Python3 installed in your system)
PYTHON3=python3

# Keyfile
keyfile=$scoring_dir/mapping3.txt

function get_langID()
{
	case $1 in
		"Albanian") echo "alban";;
		"Czech") echo "czech";;
		"Chinese") echo "mandn";;
		"Portuguese") echo "PORTU";;
		"Romanian") echo "roman";;
		"Slovak") echo "svkbn";;
	esac
}

for system in $(cat $systems); do
	echo $(basename $system)

	gunzip $system/*.gz

	# The strings 'eval' or 'dev' in the system name determine the groundtruth to be used
	dev_eval=$(basename $system | sed -E 's/.*(dev|DEV|eval|EVAL).*/\1/' | sed 's/EVAL/eval/' | sed 's/DEV/dev/')

	echo "Set of queries: $dev_eval"

	# We determine whether a floor score has to be used or not
	floor=$(basename $system | sed -E 's/.*_([^_]*)/\1/')

	echo "Floor score: $floor"

	s_full=$(ls $system/*.stdlist.xml)

	for lang in Albanian Chinese Czech Portuguese Romanian Slovak; do

		echo "Language: $lang"

		langID=$(get_langID $lang)

		if [[ ! -e  ${lang}_utts.txt ]]; then
			cat $keyfile | grep "^${langID}" | grep -v "${langID}_dev" | grep -v "${langID}_eval" | cut -f 2 > ${lang}_utts.txt
		fi
		if [[ ! -e  ${lang}_${dev_eval}.txt ]]; then
			cat $keyfile | grep "^${langID}_${dev_eval}" | cut -f 2 > ${lang}_${dev_eval}.txt
		fi

		# Target directory, where results will be stored
		mkdir $system/$lang

		s_lang=$system/$lang/${lang}-$(basename ${s_full})

		$PYTHON3 $scoring_dir/filter_std_perlang.py ${lang}_utts.txt ${lang}_${dev_eval}.txt ${s_full} ${s_lang}

		groundtruth=groundtruth_quesst2015_"$dev_eval"_"$lang"

		if [[ $floor == "auto" ]]; then
			$scoring_dir/score-TWV-Cnxe.sh $system/$lang $scoring_dir/$groundtruth
		else
			$scoring_dir/score-TWV-Cnxe.sh $system/$lang $scoring_dir/$groundtruth $floor
		fi

		gzip ${s_lang}
	done

	gzip ${s_full}

	echo ""
done

for lang in Albanian Chinese Czech Portuguese Romanian Slovak; do
	if [[ -e ${lang}_utts.txt ]]; then rm ${lang}_utts.txt; fi
	if [[ -e ${lang}_dev.txt ]]; then rm ${lang}_dev.txt; fi
	if [[ -e ${lang}_eval.txt ]]; then rm ${lang}_eval.txt; fi
done
